@@ -79,7 +79,7 @@ from importlib.machinery import ModuleSpec
 from types import ModuleType
 from typing import Any, AnyStr, Dict, Generator, Iterable, List, Optional, Tuple, Union
 
-__version__ = '0.3.25'
+__version__ = '0.3.27'
 
 
 DOCS_FOLDER = 'docs'                            #: project documentation root folder name
@@ -172,6 +172,24 @@ def camel_to_snake(name: str) -> str:
     return "".join(str_parts)
 
 
+def deep_dict_update(data: dict, update: dict):
+    """ update the optionally nested data dict in-place with the items and sub-items from the update dict.
+
+    :param data:                dict to be updated/extended. non-existing keys of dict-sub-items will be added.
+    :param update:              dict with the [sub-]items to update in the :paramref:`.data` dict.
+
+    .. hint:: the module/portion :mod:`ae.deep` is providing more deep update helper functions.
+
+    """
+    for upd_key, upd_val in update.items():
+        if isinstance(upd_val, dict):
+            if upd_key not in data:
+                data[upd_key] = {}
+            deep_dict_update(data[upd_key], upd_val)
+        else:
+            data[upd_key] = upd_val
+
+
 def duplicates(values: Iterable) -> list:
     """ determine all duplicates in the iterable specified in the :paramref:`.values` argument.
 
@@ -278,11 +296,14 @@ def main_file_paths_parts(portion_name: str) -> Tuple[Tuple[str, ...], ...]:
     :param portion_name:        portion or package name.
     :return:                    tuple of tuples of main/version file name path parts.
     """
-    return (('main' + PY_EXT, ),
-            ('__main__' + PY_EXT, ),
-            ('__init__' + PY_EXT, ),
-            (portion_name + PY_EXT, ),
-            (portion_name, PY_INIT))
+    return (
+        ('main' + PY_EXT, ),
+        ('__main__' + PY_EXT, ),
+        (PY_INIT, ),
+        ('main', PY_INIT),          # django main project
+        (portion_name + PY_EXT, ),
+        (portion_name, PY_INIT),
+    )
 
 
 def norm_line_sep(text: str) -> str:
